@@ -15,16 +15,22 @@ use Wx_dnav;
 use Wx qw[:everything];
 
 sub new {
-	 my ( $class, $href ) = @_;
-
-	  my $self = {
+	 my $class = shift;
+	 # , $href ) = @_;
+         
+	  my %arg = ref $_[0] eq "HASH" ? %{$_[0]} : ( @_ );
+	 my $self;
+	@$self{qw(dnav_top)} = delete @arg{qw(dnav)};
+       	@$self{keys %arg} = values (%arg);
+=for comment
+	  {
    	xrcfolder => $$href{xrcfolder},
 	schema => $$href{schema},
 	dnav_top => $$href{dnav},
 	panel_to => $$href{panel_to},
 	countryid => $$href{countryid},
    };
-
+=cut
     $self->{log} = Log::Log4perl->get_logger(__PACKAGE__);
 $self->{log}->debug(" new form ");
 
@@ -47,11 +53,11 @@ $self->{log}->debug(" new form ");
 # (Dumper $rs->as_query);
 #die $rs->count;
 
-	my $dman = Gtk2::Ex::DbLinker::DbcDataManager->new({
+	my $dman = Gtk2::Ex::DbLinker::DbcDataManager->new(
 			rs => $rs,
-			});
+			);
 
-		$self->{sform} = Wx::Perl::DbLinker::Wxform->new({
+		$self->{sform} = Wx::Perl::DbLinker::Wxform->new(
 		data_manager => $dman,
 		builder => $self->{dnav},
 		datawidgets => [qw(countryid langid langid1)],
@@ -61,30 +67,30 @@ $self->{log}->debug(" new form ");
 		datawidgets_ro => [qw(langid1)],
 		datawidgets_changed => {langid1=> sub{ on_langid1_changed(@_, $self) } },
 		after_update => sub{ on_after_update($self, $self->{dnav}, $dman, "form"); },
-			});
+			);
 
-		my $combodata = Gtk2::Ex::DbLinker::DbcDataManager->new({
+		my $combodata = Gtk2::Ex::DbLinker::DbcDataManager->new(
 				rs => $self->{schema}->resultset('Langue')->search_rs(undef, {order_by => 'langue' }),
 				#{columns => ['langue', {langid2 => 'langid'}],
-			});
+			);
 		
-		$self->{sform}->add_combo({
+		$self->{sform}->add_combo(
 			data_manager => $combodata,
 		    	id => 'langid',
 			builder => $self->{dnav},
-			});
+			);
 		#fields => [qw(langid langue)],
 
 
 		$self->{langid} = $self->{sform}->get_data_manager->get_field('langid1');
 		#die $self->{langid};
-		my $list =  Gtk2::Ex::DbLinker::DbcDataManager->new({
+		my $list =  Gtk2::Ex::DbLinker::DbcDataManager->new(
 				rs => $self->{schema}->resultset('Speak')->search_rs({langid => $self->{langid}, countryid => {'!=' => $self->{countryid} }}),
-			});
+			);
 
-		 $combodata = Gtk2::Ex::DbLinker::DbcDataManager->new({
+		 $combodata = Gtk2::Ex::DbLinker::DbcDataManager->new(
 				rs => $self->{schema}->resultset('Country')->search_rs(undef, { order_by => 'country'} ),
-			});
+			);
 
 
 		#set up the datasheet
@@ -110,20 +116,12 @@ $self->{log}->debug(" new form ");
 			after_update => => sub{ on_after_update($self, $self->{sf_list}->{dnav}, $list, "grid"); },
 		
 		};
-
 		#my $grid = $self->{dnav}->load_grid({ top_panel=> $top_panel, dest_name=>"m_panel_for_content", datasheet_param =>$dsparam});
 		$self->{grid} = $self->{dnav}->load_grid({bg=> wxCYAN, top_panel=> $top_panel, dest_name=>"m_panel_for_content", datasheet_param =>$dsparam});
 
-	
-	
-
-	
 	        $self->{sf_list}->{dnav}->set_form($self->{grid});
-
 		$self->{sf_list}->{dnav}->connect_signal_for("b_add",\&on_add_lst_clicked, $self);
-
 		$self->{grid}->update; 
-		 
 		$self->{sform}->add_childform($self->{grid});
 
 		 # on_countryid_changed($self, $self->{sform}->get_widget_value('countryid'));
