@@ -1,18 +1,12 @@
 
 use strict;
 use warnings;
-use lib qw(lib ../lib/ ../../hg_Gtk2-Ex-DbLinker-DbTools/lib/);
-
+#use lib qw(lib ../lib/ ../../hg_Gtk2-Ex-DbLinker-DbTools_dev/lib/);
 use Dbc::Schema;
-
 use Log::Log4perl;
   Log::Log4perl->init("log.conf"); 
-
-
 use Forms::Langues_dbc;
 
-
-
 sub get_schema {
 	my  $file = shift;
 	my $dsn = "dbi:SQLite:dbname=$file";
