@@ -52,19 +52,20 @@ use constant {
 #use constant STATUS_LAB => qw(sync !!! new del lck);
 use constant STATUS_LAB =>(' ', '!', '*', 'x', 'o');
 sub new {
-    my ($class, $frame, $req) = @_;
-
-	 my $self = $class->SUPER::new($frame,  wxID_ANY);
+	#my ($class, $frame, $req) = @_;
+	my $class = shift;
+	my %def = (borders_size => [2,20], fields => undef);
+	 my %arg = ref $_[0] eq "HASH" ? (%def, %{$_[0]}) : (%def, @_);
+	 my $self = $class->SUPER::new($arg{parent_widget},  wxID_ANY);
 	 
-	 $self->{dman} = $$req{data_manager};
-	$self->{fields} = $$req{fields}  || undef;
-	#$self->{null_string} = $$req{null_string} || "null";
-	$self->{on_changed} = $$req{on_changed}; # Code that runs when a record is changed ( any column )
-	$self->{on_row_select} = $$req{on_row_select};
-	$self->{after_update} = $$req{after_update};
-	$self->{borders_size} = $$req{borders_size} || [22, 20]; #array ref of row1 height and col1 width
-	#$self->{multi_select} = $$req{multi_select};
-
+	 $self->{dman} = $arg{data_manager};
+	 #$self->{fields} = $$req{fields}  || undef;
+	$self->{fields} = $arg{fields};
+	$self->{on_changed} = $arg{on_changed}; # Code that runs when a record is changed ( any column )
+	$self->{on_row_select} = $arg{on_row_select};
+	$self->{after_update} = $arg{after_update};
+	#$self->{borders_size} = $$req{borders_size} || [22, 20]; #array ref of row1 height and col1 width
+	$self->{borders_size} = $arg{borders_size};
 
 
 	 $self->{log} = Log::Log4perl->get_logger(__PACKAGE__);
@@ -247,7 +248,13 @@ sub _setup_grid {
 				    #$pos et l'index de id dans ce vecteur
 				    my $pos = $self->_find_index($id, @$val);
 				    # $text est le text a afficher dans la cellule  la place du id
-				    my $text = $self->{combo_val}->{$field->{name} }->[$pos];
+
+				    my $text; 
+				    if ($pos > -1) {
+					   $text = $self->{combo_val}->{$field->{name} }->[$pos];
+				   } else {
+				   		$text = "";
+				   }
 				    # combo_cur contient l'id de la derniere ligne affichee de la grid
 				    # $self->{combo_cur}->{$field->{name}} = $self->{combo_id}->{ $field->{name} }->[$pos];
 				    #$self->{log}->debug( $field->{name}, " id: ", $id, " text: ", $text);
@@ -1150,56 +1157,59 @@ L<Wx::Perl::DbLinker>
 
 The code build a table having 6 columns: 3 text entries, 2 combo, 1 toogle. A dataManager object is needed for each combo, and a dataManager for the table itself. The example here use Rose::DB::Object to access the tables.
 
-This gets the Rose::DB::Object::Manager (Plain sql command and DBI, or DBIx::Class object could have been used instead) 
+This gets the RdbDataManager that will populate the datasheet 
 
-    	my $datasheet_rows = Rdb::Mytable::Manager->get_mytable(sort_by => 'field1');
+    	my $datasheet_rows = Gtk2::Ex::DbLinker::DbcDataManager->new(
+		rs => $self->{schema}->resultset('Speak')->search_rs(
+			{langid => $self->{langid}, countryid => {'!=' => $self->{countryid} }}
+								)
+				); 
 
-This object is used to instanciante a RdbDataManager, that will be used in the datasheet constructor.
 
-      	my $dman = Gtk2::Ex::DbLinker::RdbDataManager->new({data => $datasheet_rows, meta => Rdb::Mytable->meta });
-
-The RdbDataManager for the combo rows is created:
+If the grid hold combo(s), the RdbDataManagers for those combo rows are created:
      
-       	my $combo_data = Rdb::Combotable::Manager->get_combotable( select => [qw/t1.id t1.name/], sort_by => 'name');
-	my $dman_combo_1 = Gtk2::Ex::DbLinker::RdbDataManager->new({data => $combo_data, meta => Rdb::Combotable->meta});
-
-
-	my $combo2_data =  Rdb::Combotable2::Manager->get_combotable2( sort_by => 'country');
-	my $dman_combo_2 = Gtk2::Ex::DbLinker::RdbDataManager->new({ 
-					     		data =>$combo2_data,
-						        meta => Rdb::Combotable2->meta,
-							});
+		 $combodata = Gtk2::Ex::DbLinker::DbcDataManager->new(
+				rs => $self->{schema}->resultset('Country')->search_rs(undef, { order_by => 'country'} ),
+			);
+They will be passed as parameters when C< Wx::Perl::DbLinker::Wxdatasheet->new()> is called.
 
 The Wxdatasheet object with the columns description is created:
 
+	my $grid = Wx::Perl::DbLinker::Wxdatasheet->new( 
+		parent_widget=>$scrolledwindow, 
+		fields => [
+				{name=>"countryid",
+					renderer => "combo",	header_markup => "Country", data_manager=> $combodata, fieldnames => ["countryid", "country"],
+					},	
+				   {name=>"langid", renderer=>"hidden"},
+				
+		        	],
+			after_update => => sub{ on_after_update($self, $self->{sf_list}->{dnav}, $list, "grid"); },
+		borders_size => [20, 25], #horizontal: row_1: heigth, vertical : col_1: witdh
+		
+	    );
+
+C<$scrolledwindow> is the widget that will received the grid. It is created before the grid creation:
+
        #$where_name is the name of the panel that will receive the grid
 	my $where = Wx::Window::FindWindowById( Wx::XmlResource::GetXRCID($where_name), $top_panel );
 	my $s = $where->GetSizer();
 	$s = ( defined $s ? $s :  Wx::BoxSizer->new(wxVERTICAL));
-	my $sw = Wx::ScrolledWindow->new($where, wxID_ANY); #,    Wx::Point->new(0, 0), Wx::Size->new(400, 400),  wxVSCROLL | wxHSCROLL); 
-	$sw->SetScrollbars(1,1,1,1);
-	$s->Add($sw, 1, wxALL|wxEXPAND, 1);
+	my $scrolledwindow = Wx::ScrolledWindow->new($where, wxID_ANY); #,    Wx::Point->new(0, 0), Wx::Size->new(400, 400),  wxVSCROLL | wxHSCROLL); 
+	$scrolledwindow->SetScrollbars(1,1,1,1);
+	$s->Add($scrolledwindow, 1, wxALL|wxEXPAND, 1);
 	$where->SetSizer($s);
 
-        my $dsparam =  { 
-		    fields => $sfref->{fields}, 
-		    data_manager =>  $sfref->{rs},
-		    on_row_select => sub  { $self->on_row_select($self->{sf}->{$sfname}, $sfname, $self->{sf}->{$sfname}->{pk})},
-		    on_changed => sub {$self->on_row_changed($self->{sf}->{$sfname})},
-		    borders_size => [20, 25], #horizontal: row_1: heigth, vertical : col_1: witdh
-		    };
+Once the grid has been created, it is added to C<$scrolledwindow>:
 
-	my $grid = Wx::Perl::Wxdatasheet->new($sw, $dsparam);
-	
         $s = Wx::BoxSizer->new(wxVERTICAL);
-	$sw->SetSizer($s);
+	$scrolledwindow->SetSizer($s);
 	$s->Add($grid, 1, wxALL|wxEXPAND, 1);
 
 To change the rows displayed in the table, the new set of rows is fetched.  An object derived from Rose::DB::Object::Manager is passed to the Gt2::Ex::DbLinker::RdbDatamanager object using the query method:
 
-	  my $data =  Rdb::Mytable::Manager->get_mytable(query =>[pk_field =>{eq=> $primarykey_value}], sort_by => 'field1');
-	  $self->{dataseet}->get_data_manager->query($data);
-	  $self->{datasheet}->update();
+	$grid->get_data_manager->query( $self->{schema}->resultset('Speak')->search_rs({langid => $new_value, countryid => {'!=' => $self->{countryid}} })  );
+	$grid->update;
 
 =head1 DESCRIPTION
 
@@ -1238,13 +1248,19 @@ You would then typically connect some buttons to methods such as inserting, dele
 
 =head2 constructor
 
-The C<new()> method expects a Wx::window object and a hash reference of key / value pairs.
+The C<new()> method expects a list of parameters name and value or a hash reference of  parameters name (keys) / value pairs.
+
+The parameters are:
 
 =over
 
+=item *
+
+C<parent_widget> a Wx::window object
+
 =item * 
 
-C<data_manager> a instance of a xxxDataManager object.
+C<data_manager> a instance of a xxxDataManager object to populate the grid.
 
 =item *
 
@@ -1260,7 +1276,7 @@ C<border_size> an array ref that holds the height of the field labels row and th
 
 =item *
 
-C<fields> a reference to an array of hash. Each hash has the following key / value pairs.
+C<fields> a reference to an array of hash. Each hash defined a field, and has the following key / value pairs:
 
 =over
 
@@ -1375,7 +1391,7 @@ FranE<ccedil>ois Rappaz <rappazf@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2015 by FranE<ccedil>ois Rappaz.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2016 by FranE<ccedil>ois Rappaz.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
 =cut
 
