@@ -60,7 +60,10 @@ my %getter = (
 
 
 sub new {
-	my ($class, $req)=@_;
+	my $class = shift;
+	#my $class, $req)=@_;
+	my %def = (null_string => "null", rec_spinner=>"RecordSpinner", status_label=>"lbl_RecordStatus", rec_count_label=>"lbl_RecordCount", locale=>"fr_CH", auto_apply=>1);
+=for comment
 	my $self ={
 		dman => $$req{data_manager},
 		cols => $$req{datawidgets},
@@ -81,6 +84,11 @@ sub new {
 		auto_apply =>  (defined $$req{auto_apply} ?  $$req{auto_apply}  : 1),
 	
 	};
+=cut
+  	my %arg = (ref $_[0] eq "HASH" ? (%def, %{$_[0]}) : (%def, @_));
+	my $self;
+	@$self{qw(dman cols ecols)} = delete @arg{qw(data_manager datawidgets datawidgets_changed)};
+	@$self{keys %arg} = values (%arg);
 	 bless $self, $class;
 	 #$self->{cols} = [];
 	 $self->_init;
@@ -223,8 +231,11 @@ sub add_combo_values {
 #set the hash ref of id => row# in $self->{datawidgetsPos}->{$field}
 #set the combo's datamanager in $self->{comboDman}->{$field}
 sub add_combo{
-	my ($self, $req)=@_;
-
+	#my ($self, $req)=@_;
+	my $self = shift;
+	my %def = (init => 1);
+	my %h;
+	my $req =  (ref $_[0] eq "HASH")? $_[0] : (%h =(%def, @_)) && \%h;
 	my $combo = {
 		dman => $$req{data_manager}, 
 		id => $$req{id},
@@ -1037,6 +1048,7 @@ sub update{
 	my @col = $self->{dman}->get_field_names;
 	$self->{log}->debug("update cols are " . (@col ? join(" " , @col) : " cols undef "));
 	if ( $self->{dman}->row_count > 0) {
+		$self->{rec_spinner}->SetValue(1) if ($self->{rec_spinner});
 		$self->_display_data(0); 
 	} else {
 		$self->_display_data(-1)
@@ -1131,11 +1143,11 @@ This gets the Rose::DB::Object::Manager (we could have use plain sql command, or
 
 	my $data = Rdb::Mytable::Manager->get_mytable(query => [pk_field => {eq => $value]);
 
-	my $dman = Gtk2::Ex::DbLinker::RdbDataManager->new({data=> $data, meta => Rdb::Mytable->meta });
+	my $dman = Gtk2::Ex::DbLinker::RdbDataManager->new(data=> $data, meta => Rdb::Mytable->meta );
 
 This create the form.
 
-		$self->{form_coll} = Wx::Perl::DbLinker::Wxform->new({
+		$self->{form_coll} = Wx::Perl::DbLinker::Wxform->new(
 			data_manager => $dman,
 			builder => 	$builder,
 		  	rec_spinner => $self->{dnav}->get_object('RecordSpinner'),
@@ -1147,7 +1159,7 @@ This create the form.
 				field_id2 => ["%Y-%m-%d", "%d-%m-%Y"], },
 			time_zone => 'Europe/Zurich',
 			locale => 'fr_CH',
-	    });
+	    );
 
 C<$builder> is an object that has a C<get_object($name)> method described below and frame method that return the main frame.
 
@@ -1203,13 +1215,13 @@ An other way is to create a data manager for the transaction table
 
 With DBI
 
-	$dman = Gtk2::Ex::DbLinker::DbiDataManager->new({ dbh => $self->{dbh}, sql =>{select =>"no_seller, no_product", from => "transaction", where => ""}});
+	$dman = Gtk2::Ex::DbLinker::DbiDataManager->new( dbh => $self->{dbh}, sql =>{select =>"no_seller, no_product", from => "transaction", where => ""});
 
 With Rose::DB::Object
 
 	$data = Rdb::Transaction::Manager->get_transaction(query=> [no_seller => {eq => $current_seller }]);
 
-	$dman = Gtk2::Ex::DbLinker::RdbDataManager->new({data => $data, meta=> Rdb::Transaction->meta});
+	$dman = Gtk2::Ex::DbLinker::RdbDataManager->new(data => $data, meta=> Rdb::Transaction->meta);
 
 And keep a reference of this for latter
 
@@ -1281,7 +1293,9 @@ such as inserting, moving, deleting, etc.
 
 =head2 constructor
 
-The C<new();> method expects a hash reference of key / value pairs
+The C<new();> method expects a list of parameter name => value or a hash reference of parameter name (key) / value pairs
+
+The parameters are:
 
 =over
 
@@ -1304,7 +1318,7 @@ C<$builder> is an object that must have a C<get_object($object_name)> which is a
 
 =back
 
-The following keys are optional
+The following parameters are optional
 
 =over
 
@@ -1319,7 +1333,7 @@ widget called RecordSpinner.
 
 =item *
 
-C<rec_count_label>  name (default to "lblRecordCount") or a reference to a label that indicate the position of the current row in the rowset
+C<rec_count_label>  name (default to "lbl_RecordCount") or a reference to a label that indicate the position of the current row in the rowset
 
 =item *  
 
@@ -1341,10 +1355,11 @@ C<auto_apply> defaults to 1, meaning that apply will be called if a changed has
 
 C<datawidgets_changed> is a hash ref having the field's name as keys and a code ref that will be called when the field content is changed.
 
-		$self->{sform} = Wx::Perl::DbLinker::Wxform->new({
-		...
-		datawidgets_changed => {langid=> sub{ on_langid_changed(@_, $self) } },
-			});
+		$self->{sform} = Wx::Perl::DbLinker::Wxform->new(
+			...
+			datawidgets_changed => {langid=> sub{ on_langid_changed(@_, $self) } },
+			
+		);
 
 		sub on_langid_changed {
 			my ($widget, $event, $self) = @_;
@@ -1362,14 +1377,14 @@ C<datawidgets_ro> is an array ref that gives the field's name that will be read-
 
 =back
 
-=head2 C<add_combo( {	data_manager =E<gt> $dman, 	id =E<gt> 'noed',  fields =E<gt> ["id", "nom"], }); >
+=head2 C<add_combo( data_manager =E<gt> $dman, 	id =E<gt> 'noed',  fields =E<gt> ["id", "nom"] ); >
 
 Once the constructor has been called, combo designed in the xrc file received their rows with this method. 
 Two Wx objects are supported Wx::ListCtrl and Wx::Combo.
 
 C<return value> an array ref of the first field values is returned since in you have to retrieve the index of the selected row (holding nom values) to access the corresponding id
 
-C<parameters> a hash reference, and the key and value are
+C<parameters> is a list of paramater name => value or a hash reference of key (parameter name) and value, and the parameters are:
 
 =over
 
@@ -1387,7 +1402,7 @@ C<fields> an array reference holdings the names of fields in the combo (this par
 
 =back
 
-=head2 C< Wx::Perl::DbLinker::Wxform-E<gt>add_combo({	data_manager =E<gt> $combodata, id =E<gt> 'countryid',	builder =E<gt> $builder,   }); >
+=head2 C< Wx::Perl::DbLinker::Wxform-E<gt>add_combo( data_manager =E<gt> $combodata, id =E<gt> 'countryid',	builder =E<gt> $builder ); >
 
 This method can also be called as a class method, when the underlying form is not bound to any table. You need to pass the builder object (described above) as a supplemental parameter.
 
